"use client";
import { useRef, useState } from "react";
import IconBox from "@/components/IconBox";
import { motion } from "framer-motion";

interface IFAQ {
    index?: number;
    question: string;
    answer: string;
}

function FAQ({ index, question, answer }: IFAQ) {
    const [isOpen, setIsOpen] = useState<boolean>(false);

    const contentRef = useRef<HTMLDivElement>(null);

    return (
        <motion.div
            initial={{ opacity: 0 }}
            whileInView={{ opacity: 1 }}
            transition={{ delay: index ? 0.6 + index * 0.2 : 0.6 }}
            viewport={{ once: true }}
            onClick={() => setIsOpen(!isOpen)}
            className={`relative w-full p-6 border ${
                isOpen ? "border-white/5 bg-[#0CE77E]/10" : "border-white/5 bg-[#0E1618]"
            } cursor-pointer duration-200`}
        >
            <p className={`font-serif text-lg font-medium ${isOpen ? "text-[#0CE77E]" : "text-white"} duration-200`}>
                {question}
            </p>

            <div
                ref={contentRef}
                className={`${isOpen ? "pt-[10px]" : ""} duration-300 overflow-hidden`}
                style={{
                    maxHeight: isOpen
                        ? `${contentRef.current?.scrollHeight ? contentRef.current?.scrollHeight + 10 : "0"}px`
                        : "0px",
                }}
            >
                <p
                    dangerouslySetInnerHTML={{
                        __html: answer,
                    }}
                    className="text-white"
                ></p>
            </div>

            <span className={`absolute -top-px -left-px ${!isOpen ? "opacity-0" : ""} duration-200`}>
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M13 1.00037L1 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className={`absolute -bottom-px -left-px ${!isOpen ? "opacity-0" : ""} duration-200`}>
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M13 12L1 12" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className={`absolute -top-px -right-px ${!isOpen ? "opacity-0" : ""} duration-200`}>
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M12 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M0 1.00037L12 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className={`absolute -bottom-px -right-px ${!isOpen ? "opacity-0" : ""} duration-200`}>
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M12 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M0 12L12 12" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>
        </motion.div>
    );
}

export default function ArchitectureSection() {
    const faqs: IFAQ[] = [
        {
            question: "GridLink Decentralized Network",
            answer: "The platform operates on a peer-to-peer network leveraging a custom protocol called GridLink. GridLink dynamically discovers available GPUs and establishes secure, low-latency connections. This architecture removes single points of failure and ensures high availability across the system.",
        },
        {
            question: "EdgeNode Client - GPU Resource Sharing",
            answer: "Idle GPUs are integrated into the network via the EdgeNode client. This lightweight software runs minimal background processes and uses a predictive algorithm called QuantumMesh to anticipate demand, ensuring optimal resource utilization. GPUs report their availability, specifications, and thermal status in real-time.",
        },
        {
            question: "HiveMind Engine For Computing Resource Orchestration",
            answer: "Orchestration is powered by the HiveMind engine, a distributed AI-powered scheduler. HiveMind uses neural topology mapping to allocate workloads intelligently, balancing computational loads while minimizing latency. It also supports cross-node task migration, enabling seamless scaling for complex jobs.",
        },
        {
            question: "Security and Privacy",
            answer: "The platform employs QRE encryption to secure communications and transactions, ensuring protection against future quantum-based threats. Computation on GPUs is sandboxed using a proprietary system called Isolated Compute Layers (ICL), which prevents interference or data leaks between tasks.",
        },
        {
            question: "Scalability and Fault Tolerance",
            answer: "The architecture is inherently scalable through a self-healing protocol. When nodes fail or become unresponsive, it re-routes tasks and replicates workloads in milliseconds, ensuring uninterrupted performance. This protocol also supports edge deployments in remote or low-bandwidth environments.",
        },
        {
            question: "Adaptive Dynamic Compression Layer",
            answer: "A unique feature of the platform is the Adaptive Compression Layer (ACL), which reduces data transfer overhead by analyzing workload patterns and applying context-aware compression. This allows for faster data transfers, especially for high-volume tasks like rendering and training deep learning models.",
        },
        {
            question: "PredictAMI - Predictive Maintenance Analytics",
            answer: "GPU providers benefit from PredictAMI, a built-in monitoring system that predicts hardware failures before they occur. Using machine learning models trained on thermal data, voltage patterns, and workload history, PredictAMI helps avoid downtime and prolongs the lifespan of hardware.",
        },
        {
            question: "Energy Optimization Framework",
            answer: "The system features EcoFlow, an energy optimization framework that monitors power consumption and dynamically adjusts workloads to minimize energy usage. EcoFlow also incentivizes the use of renewable energy by offering ComputeCoin bonuses for eco-friendly nodes.",
        },
    ];

    return (
        <section id="architecture" className="border-b border-white/10">
            <div className="mx-auto container max-w-[1435px] px-8">
                <div className="p-24 flex flex-col items-center">
                    <motion.div initial={{ opacity: 0 }} whileInView={{ opacity: 1 }} viewport={{ once: true }}>
                        <IconBox
                            icon={
                                <svg
                                    width="15"
                                    height="14"
                                    viewBox="0 0 15 14"
                                    fill="none"
                                    xmlns="http://www.w3.org/2000/svg"
                                >
                                    <path
                                        d="M6.04163 1.16699V2.33366"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M8.95831 1.16699V2.33366"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M6.04163 11.667V12.8337"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M8.95831 11.667V12.8337"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M13.3333 8.4585H12.1666"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M2.83329 5.54199H1.66663"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M2.83329 8.4585H1.66663"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M13.3333 5.54199H12.1666"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M7.90476 4.9585L6.68501 6.43859C6.55429 6.5972 6.64797 6.82545 6.86112 6.86769L8.13886 7.1208C8.36612 7.16583 8.45281 7.41847 8.29391 7.5727L6.78051 9.04183"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M2.83331 7.00016C2.83331 4.80027 2.83331 3.70033 3.51673 3.01691C4.20015 2.3335 5.30009 2.3335 7.49998 2.3335C9.69985 2.3335 10.7998 2.3335 11.4832 3.01691C12.1666 3.70033 12.1666 4.80027 12.1666 7.00016C12.1666 9.20003 12.1666 10.3 11.4832 10.9834C10.7998 11.6668 9.69985 11.6668 7.49998 11.6668C5.30009 11.6668 4.20015 11.6668 3.51673 10.9834C2.83331 10.3 2.83331 9.20003 2.83331 7.00016Z"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinejoin="round"
                                    />
                                </svg>
                            }
                            text="ARCHITECTURE"
                        />
                    </motion.div>

                    <motion.h2
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        transition={{ delay: 0.2 }}
                        viewport={{ once: true }}
                        className="my-4 font-serif text-[42px] font-medium leading-[64px] text-white"
                    >
                        Architecture for the <span className="text-[#0CE77E]">generations</span> to come
                    </motion.h2>

                    <motion.p
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        transition={{ delay: 0.4 }}
                        viewport={{ once: true }}
                        className="mb-12 max-w-[900px] text-lg font-light text-center text-white/75"
                    >
                        Built for scalability, security, and efficiency, Vertex’s architecture is designed to evolve
                        with the ever-changing landscape of computing.
                    </motion.p>

                    <div className="w-full grid gap-6">
                        {faqs.map((faq, index) => (
                            <FAQ key={index} index={index} question={faq.question} answer={faq.answer} />
                        ))}
                    </div>
                </div>
            </div>
        </section>
    );
}
