"use client";
import IconBox from "@/components/IconBox";
import logoImg from "@/assets/images/brand/logo.svg";
import Image from "next/image";
import { motion } from "framer-motion";

export default function ManifestoSection() {
    return (
        <section id="manifesto" className="border-b border-white/10">
            <div className="mx-auto container max-w-[1435px] px-8">
                <div className="p-24 flex flex-col items-center">
                    <motion.div initial={{ opacity: 0 }} whileInView={{ opacity: 1 }} viewport={{ once: true }}>
                        <IconBox
                            icon={
                                <svg
                                    width="14"
                                    height="14"
                                    viewBox="0 0 14 14"
                                    fill="none"
                                    xmlns="http://www.w3.org/2000/svg"
                                >
                                    <path
                                        d="M11.9584 6.12533V5.83366C11.9584 3.63377 11.9584 2.53383 11.275 1.85041C10.5915 1.16699 9.49161 1.16699 7.29169 1.16699H6.70841C4.50857 1.16699 3.40863 1.16699 2.72522 1.8504C2.0418 2.53381 2.04179 3.63375 2.04177 5.83362L2.04175 8.45866C2.04173 10.3763 2.04172 11.3352 2.57134 11.9805C2.66832 12.0987 2.77667 12.207 2.89483 12.3041C3.5402 12.8337 4.49903 12.8337 6.41669 12.8337"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M4.375 4.08374H9.625"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M4.375 7.00037H7.875"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                    <path
                                        d="M11.9583 11.667V9.91699C11.9583 9.08318 11.1748 8.16699 10.2083 8.16699C9.24173 8.16699 8.45825 9.08318 8.45825 9.91699V11.9587C8.45825 12.4419 8.85002 12.8337 9.33325 12.8337C9.81649 12.8337 10.2083 12.4419 10.2083 11.9587V9.91699"
                                        stroke="#0CE77E"
                                        strokeWidth="0.875"
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                    />
                                </svg>
                            }
                            text="Manifesto"
                        />
                    </motion.div>

                    <motion.h2
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        transition={{ delay: 0.2 }}
                        viewport={{ once: true }}
                        className="my-4 font-serif text-[42px] font-medium leading-[64px] text-white"
                    >
                        A future where computing is <span className="text-[#0CE77E]">accessible</span> to all
                    </motion.h2>

                    <motion.p
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        transition={{ delay: 0.4 }}
                        viewport={{ once: true }}
                        className="mb-12 max-w-[900px] text-lg font-light text-center text-white/75"
                    >
                        We believe in a world where high-performance computing is no longer a privilege but a right.
                        Vertex is committed to democratizing GPU access for everyone.
                    </motion.p>

                    <motion.div
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        transition={{ delay: 0.6 }}
                        viewport={{ once: true }}
                        className="relative w-full py-8 px-10 border border-[#0CE77E]/5 bg-[#0CE77E]/10"
                    >
                        <p className="mb-8 leading-[24px] text-white">
                            Computing is at a crossroads. As artificial intelligence, rendering, and simulation demand
                            unprecedented computational power, GPUs have become the engines of progress. Yet, the way we
                            access and utilize these resources is stuck in the past. <br />
                            <br />
                            Centralized data centers are bottlenecks. They are expensive, vulnerable to outages, and
                            often underutilized. Meanwhile, millions of GPUs across the globe sit idle in gaming rigs,
                            personal devices, and edge systems, wasted potential waiting to be unlocked. <br />
                            <br />
                            This is where decentralization changes everything. <br />
                            <br />
                            By connecting unused GPUs into a shared, global network, we can create an open, accessible,
                            and infinitely scalable pool of compute power. A decentralized GPU renting system isn’t just
                            a technical innovation—it’s a rethinking of resource ownership and accessibility. <br />
                            <br />
                            • For developers and researchers, it offers cost-effective, on-demand access to
                            computational power. <br />
                            • For individuals and businesses, it turns idle hardware into revenue streams. <br />
                            • For the world, it means reduced waste, democratized technology, and a level playing field
                            for innovation. <br />
                            <br />
                            The time for this transformation is now. The infrastructure is ready: blockchain for trust,
                            peer-to-peer networks for connectivity, and AI for optimization. By combining these
                            technologies, we can create a system that is secure, fair, and resilient. <br />
                            <br />
                            <span className="text-[#0CE77E]">That’s why we’re building Vertex.</span> <br />
                            <br />
                            An open-source framework for decentralized GPU renting, designed to empower individuals,
                            break the monopolies of centralized clouds, and unleash the true potential of global
                            compute. <br />
                            <br />
                            The future isn’t in the hands of a few—it’s in all of ours. Let’s build it together.
                        </p>

                        <Image src={logoImg} alt="" className="w-[185px]" />

                        <span className="absolute -top-px -left-px">
                            <svg
                                width="13"
                                height="13"
                                viewBox="0 0 13 13"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path d="M1 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                                <path d="M13 1.00037L1 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -left-px">
                            <svg
                                width="13"
                                height="13"
                                viewBox="0 0 13 13"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path d="M1 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                                <path d="M13 12L1 12" stroke="#0CE77E" strokeWidth="1.5" />
                            </svg>
                        </span>

                        <span className="absolute -top-px -right-px">
                            <svg
                                width="13"
                                height="13"
                                viewBox="0 0 13 13"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path d="M12 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                                <path d="M0 1.00037L12 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                            </svg>
                        </span>

                        <span className="absolute -bottom-px -right-px">
                            <svg
                                width="13"
                                height="13"
                                viewBox="0 0 13 13"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path d="M12 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                                <path d="M0 12L12 12" stroke="#0CE77E" strokeWidth="1.5" />
                            </svg>
                        </span>
                    </motion.div>
                </div>
            </div>
        </section>
    );
}
