import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import "./globals.css";
import Frame from "@/components/Frame";
import Navbar from "@/components/Navbar";
import Footer from "@/components/Footer";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "Vertex: Accelerating Possibilities of Idle GPUs Globally",
  description:
    "Vertex thrives on the power of community. By connecting users across the globe, we are creating a network that fosters collaboration, innovation, and shared success.",
  openGraph: {
    type: "website",
    url: "https://ai-proj-02.vercel.app",
    title: "Vertex: Accelerating Possibilities of Idle GPUs Globally",
    description:
      "Vertex thrives on the power of community. By connecting users across the globe, we are creating a network that fosters collaboration, innovation, and shared success.",
    images: `https://ai-proj-02.vercel.app/og-banner.png`,
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body
        className={`${geistSans.variable} ${geistMono.className} antialiased bg-[#070F11]`}
      >
        <Frame />
        <Navbar />
        {children}
        <Footer />
      </body>
    </html>
  );
}
