import { JSX, useState, useEffect } from "react";

interface IProps {
    icon?: JSX.Element;
    text: string;
    hasRightArrowIcon?: boolean;
    customClasses?: string;
}

export default function CopyBox({ icon, text, hasRightArrowIcon, customClasses }: IProps) {
    const [displayText, setDisplayText] = useState(text);

    useEffect(() => {
        setDisplayText(text);
    }, [text]);

    const handleClick = () => {
        navigator.clipboard.writeText(text);
        setDisplayText("Copied!");
        setTimeout(() => {
            setDisplayText(text);
        }, 2000);
    };

    return (
        <div
            onClick={handleClick}
            className={`group relative py-2 px-2.5 border border-white/5 hover:border-[#0CE77E] bg-[#0CE77E]/10 hover:bg-[#0CE77E]/25 backdrop-blur-lg flex items-center gap-2.5 text-sm font-medium uppercase text-[#0CE77E] ${customClasses} cursor-pointer duration-200`}
        >
            {icon}

            <p>CA : {displayText}</p>

            {hasRightArrowIcon && (
                <svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path
                        d="M6 12.0002L10 8.00017L6 4.00017"
                        stroke="#0CE77E"
                        strokeWidth="1.33333"
                        strokeLinecap="round"
                        strokeLinejoin="round"
                    />
                </svg>
            )}

            <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 0V4.5" stroke="#0CE77E" />
                    <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 4.5V0" stroke="#0CE77E" />
                    <path d="M5.5 4L1 4" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M5 0V4.5" stroke="#0CE77E" />
                    <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                </svg>
            </span>

            <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                <svg width="6" height="5" viewBox="0 0 6 5" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M5 4.5V0" stroke="#0CE77E" />
                    <path d="M0.5 4L5 4" stroke="#0CE77E" />
                </svg>
            </span>
        </div>
    );
}
